#
# spec file for package joda-convert
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           joda-convert
Version:        2.2.3
Release:        2.3
Summary:        Java library for conversion to and from standard string formats
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/JodaOrg/joda-convert/
Source0:        https://github.com/JodaOrg/joda-convert/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  guava
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
Java library to enable conversion to and from standard string formats.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml
dos2unix *.txt

%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin

%build
mkdir -p lib
build-jar-repository -s lib guava
ant \
  -Dproject.version=%{version} \
  clean jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt

%files javadoc
%license LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}

%changelog
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Spec file cleanup
* Thu Sep  5 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 2.2.3
  * Changes of version 2.2.3:
    + Support classes that define `@FromString` but not
    `@ToString`. This can be used to leniently parse classes
    where the format used to be a Joda-Convert class.
    + Switch LGTM to CodeQL.
  * Changes of version 2.2.2:
    + Fix deserialization of array classes. Fixes #30
  + Switch master to main.
  * Changes of version 2.2.1:
    + Ensure `ZoneRegion` is correctly converted.
  * Changes of version 2.2.0:
    + Avoid circular loops in dynamic registration of converters.
  + Optimise dynamic registration of converters.
    + Add Tidelift commercial support and security policy.
  * Changes of version 2.1.2:
    + Fix `Renamed.ini` to avoid NPE during loading. A null
    `RenameHandler.INSTANCE` could be observed if `Renamed.ini`
    referred to a class with a static initializer that referred
    back to `RenameHandler`.
  + Fix build to work on Java 11.
  * Changes of version 2.1.1:
    + Log startup issues when using renames by configuration.
  * Changes of version 2.1:
    + Register renames by configuration. Add `Renamed.ini` to
    configure renames more cleanly. Fixes #26.
  * Changes of version 2.0.2:
    + Enhance speed of numeric array parsing. Previous version used
    regex patterns, which were slower.
  * Changes of version 2.0.1:
    + Add "classic" variant for systems that can't handle
    module-info.class.
  * Changes of version 2.0:
    + Add module-info for Java 9. Fixes #21.
    + Update and redesign build to support Java 9.
    + Remove direct dependency on Guava by copying code into
    Joda-Convert. The code previously used reflection
    setAccessible() which would not work on Java 9. The best
    alternative was to copy (shaded) the relevant part of Guava
    (same license). This also allowed the converter for `Type` to
    work without Guava. Given all this, Joda-Convert no longer
    has an optional dependency on Guava. It will still adapt and
    setup a converter for `TypeToken` if Guava is present. This
    adaptation will also work on Java 9, provided the modules are
    loaded in the same layer. Fixes #20, #22.
    + Enable build to work on Java 9.
    + Dynamic Java 8 code must not extend Guava code. Incorrect
    setup of reflection-based converters. Fixes #19.
    + Avoid bridge and synthetic methods in reflection. If an
    annotation is copied to the bridge/synthetic method it causes
    trouble. Fixes #23.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not use the legacy guava20 any more
* Wed Feb  6 2019 Fridrich Strba <fstrba@suse.com>
- Initial package of java-convert 1.9.2
- Add build.xml file to allow build with ant
